@@ -974,7 +974,8 @@ class WordToken(models.Model):
 
     def getAnalysisLines(self,form):
         if self.Output is not None:
-            outline = {x: self.Output[x] for x in self.Output if x not in form['force_fetch']}
+            #outline = {x: self.Output[x] for x in self.Output if x not in form['force_fetch']}
+            outline = copy.copy(self.Output)
         else:
             outline = {}
 
